@@ -37,7 +37,7 @@ class Exceptions:
 
 class PersonalizeRuntimeClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.15/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html)
     """
 
@@ -53,7 +53,7 @@ class PersonalizeRuntimeClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.15/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#can_paginate)
         """
 
@@ -67,7 +67,7 @@ class PersonalizeRuntimeClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.15/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#generate_presigned_url)
         """
 
@@ -84,24 +84,25 @@ class PersonalizeRuntimeClient(BaseClient):
         """
         Re-ranks a list of recommended items for the given user.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.15/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_personalized_ranking)
         """
 
     def get_recommendations(
         self,
         *,
-        campaignArn: str,
+        campaignArn: str = ...,
         itemId: str = ...,
         userId: str = ...,
         numResults: int = ...,
         context: Mapping[str, str] = ...,
         filterArn: str = ...,
-        filterValues: Mapping[str, str] = ...
+        filterValues: Mapping[str, str] = ...,
+        recommenderArn: str = ...
     ) -> GetRecommendationsResponseTypeDef:
         """
         Returns a list of recommended items.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.15/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_personalize_runtime/client.html#get_recommendations)
         """
