@@ -64,33 +64,21 @@ GetPersonalizedRankingResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetRecommendationsRequestRequestTypeDef = TypedDict(
-    "_RequiredGetRecommendationsRequestRequestTypeDef",
+GetRecommendationsRequestRequestTypeDef = TypedDict(
+    "GetRecommendationsRequestRequestTypeDef",
     {
         "campaignArn": str,
-    },
-)
-_OptionalGetRecommendationsRequestRequestTypeDef = TypedDict(
-    "_OptionalGetRecommendationsRequestRequestTypeDef",
-    {
         "itemId": str,
         "userId": str,
         "numResults": int,
         "context": Mapping[str, str],
         "filterArn": str,
         "filterValues": Mapping[str, str],
+        "recommenderArn": str,
     },
     total=False,
 )
 
-
-class GetRecommendationsRequestRequestTypeDef(
-    _RequiredGetRecommendationsRequestRequestTypeDef,
-    _OptionalGetRecommendationsRequestRequestTypeDef,
-):
-    pass
-
-
 GetRecommendationsResponseTypeDef = TypedDict(
     "GetRecommendationsResponseTypeDef",
     {
